@@ -782,8 +782,8 @@ const WindowList = new Lang.Class({
             }));
         this._windowList.connect('scroll-event', Lang.bind(this, this._onScrollEvent));
 
-	let indicatorsBox = new St.BoxLayout({ x_align: Clutter.ActorAlign.END });
-	box.add(indicatorsBox);
+        let indicatorsBox = new St.BoxLayout({ x_align: Clutter.ActorAlign.END });
+        box.add(indicatorsBox);
 
         this._workspaceIndicator = new WorkspaceIndicator();
         indicatorsBox.add(this._workspaceIndicator.container, { expand: false, y_fill: true });
@@ -1165,6 +1165,9 @@ const WindowList = new Lang.Class({
 
         global.screen.disconnect(this._fullscreenChangedId);
 
+        Main.xdndHandler.disconnect(this._dragBeginId);
+        Main.xdndHandler.disconnect(this._dragEndId);
+
         this._settings.disconnect(this._groupingModeChangedId);
 
         let windows = global.get_window_actors();
@@ -1185,7 +1188,7 @@ function enable() {
 
     windowList.actor.connect('notify::hover', Lang.bind(Main.messageTray,
         function() {
-            this._pointerInTray = windowList.actor.hover;
+            this._pointerInNotification = windowList.actor.hover;
             this._updateState();
         }));
 
